Stimuli Delivery — BCI-Framework documentation

# Stimuli Delivery

Run an experiment in a dedicated space, without debugger or code editor.

class `bci_framework.framework.environments.stimuli_delivery.` `StimuliDelivery`(core)

  Dashboard for experiments executions.

  `__init__`(core)

    Constructor

  `build_dashboard`() → None

    Create the experiments selector.

  `connect`() → None

    Connect events.

  `get_free_port`() → str

    Get any free port available.

  `get_local_ip_address`() → str

    Connect to internet for get the local IP.

  `on_focus`() → None

    Update mdiAreas.

  `open_browser`() → None

    Open delivery on browser.

  `open_subwindow`(url=None) → None

    Open an auxiliar window for stimuli delivery.

  `update_experiments_list`() → None

    Update the experiments selector.

  `update_ip`(port) → None

    Update the QLineEdit with the current ip address.

  `widgets_set_enabled`() → None

    Update action buttons.